@@ -1,4 +1,4 @@
-//@line 43 "/usr/obj/ports/mozilla-thunderbird-1.5.0.10/mozilla/mail/base/content/msgMail3PaneWindow.js"
+//@line 43 "/usr/obj/ports/mozilla-thunderbird-1.5.0.12/mozilla/mail/base/content/msgMail3PaneWindow.js"
 
 /* This is where functions related to the 3 pane window are kept */
 
@@ -1566,11 +1566,6 @@ function SelectMessage(messageUri)
     gDBView.selectMsgByKey(msgHdr.messageKey);
 }
 
-function ReloadWithAllParts()
-{
-  gDBView.reloadMessageWithAllParts();
-}
-
 function ReloadMessage()
 {
   gDBView.reloadMessage();
